pub enum ShouldPanic {
No,
Yes,
YesWithMessage(&'static str),
}Expand description
Whether a test is expected to panic.
The easiest way to define a test that should panic is to use the #[should_panic] attribute
when defining the test.
#[cfg(test)]
mod tests {
use gba_test_macros::test;
#[test]
#[should_panic]
fn ignored_test() {
panic!("something was expected to go wrong");
}
}Variants
No
The test is expected to run successfully.
Yes
The test is expected to panic during execution.
YesWithMessage(&'static str)
The test is expected to panic with the given substring present in the panic message.